![ColaboHash](assets/colabohash400x218.png)

# ColaboHash

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)

Temporarily abuse Google Colab for fun, hash cracking and and definitely NOT profit! Run hashcat commands in Google's Colaboratory runtime with support of allocated GPU resources

**Requires:** Chrome browser 84+ version installed

## Getting Started

You can get started using `colabohash` by installing it through pip.

```
pip install colabohash
```

## Usage

See the `examples` folder for usage examples.

## Roadmap

- [X] Automatic hashcat command invocation in Colab
- [X] Add discord webhook callback option
- [ ] Decouple callbacks from jupyter notebook
- [ ] Add support for other drivers
- [ ] Add more examples + enhance documentation
- [ ] Add email callback option
- [ ] Enable progress status on demand

## Contributing

Any PRs are welcome!

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/apogiatzis/powsolver/tags). 

## Authors

* **Antreas Pogiatzis** - *Initial work* 

See also the list of [contributors](https://github.com/apogiatzis/powsolver/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details


